@@ -17,7 +17,6 @@ and;
 array();
 as;
 break;
-callable;
 case;
 catch;
 class ClassName;
@@ -56,7 +55,6 @@ instanceof ClassName;
 insteadof ClassName;
 interface ClassName;
 isset();
-iterable;
 list();
 namespace ClassName;
 new ClassName;
